<?php

namespace Pinpoint\PackingSlips\Block\Adminhtml\Pdf;

use Magento\Framework\View\Element\Template;

/**
 * Class PackingSlip
 * @package Pinpoint\PackingSlips\Block\Adminhtml\Pdf
 */
class PackingSlip extends Template
{
    /**
     * @var string
     */
    const SUPPORT_EMAIL_CONFIG_PATH = 'trans_email/ident_support/email';

    /**
     * @var string
     */
    const RETURN_ADDRESS_CONFIG_PATH = 'pinpoint_packingslips/packingslips/return_address';

    /**
     * @var string $_template
     */
    protected $_template = "Pinpoint_PackingSlips::pdf/packing-slip.phtml";

    /**
     * @var \Magento\GiftMessage\Helper\Message
     */
    protected $giftMessageHelper;

    /**
     * @var \Pinpoint\Core\Helper\Config
     */
    protected $configHelper;

    /**
     * PackingSlip constructor.
     * @param \Magento\GiftMessage\Helper\Message $giftMessageHelper
     * @param \Pinpoint\Core\Helper\Config $configHelper
     * @param Template\Context $context
     * @param array $data
     */
    public function __construct(
        \Magento\GiftMessage\Helper\Message $giftMessageHelper,
        \Pinpoint\Core\Helper\Config $configHelper,
        Template\Context $context,
        array $data = []
    ) {
        $this->configHelper = $configHelper;
        $this->giftMessageHelper = $giftMessageHelper;

        parent::__construct($context, $data);
    }

    /**
     * @param $address
     * @return string
     */
    public function getAddressString($address)
    {
        if (is_object($address)) {
            $address = array_filter($address->getData(), 'is_scalar');
        }

        $usePrefix = isset($address['prefix']);
        $name = sprintf('%s %s', $address['firstname'], $address['lastname']);

        if ($usePrefix) {
            $name = $address['prefix'] . '. ' . $name;
        }

        return sprintf("%s<br/>%s<br/>%s<br/>%s<br/>%s", $name, $address['street'], $address['postcode'], $address['city'], $address['telephone']);
    }

    /**
     * @param $messageId
     * @return array
     */
    public function getGiftMessage($messageId)
    {
        return $this->giftMessageHelper->getGiftMessage($messageId)->getData();
    }

    /**
     * @return string
     */
    public function getSupportEmail()
    {
        return $this->configHelper->getConfigValue(self::SUPPORT_EMAIL_CONFIG_PATH);
    }

    /**
     * @return string
     */
    public function getReturnAddress()
    {
        return $this->configHelper->getConfigValue(self::RETURN_ADDRESS_CONFIG_PATH);
    }
}